@@ -6,6 +6,7 @@ from flask import request, jsonify, Blueprint
 from openai import AsyncAzureOpenAI
 from ..batch.utilities.chat_history.auth_utils import (
     get_authenticated_user_details,
+    get_tenantid,
 )
 from ..batch.utilities.helpers.config.config_helper import ConfigHelper
 from ..batch.utilities.helpers.env_helper import EnvHelper
@@ -63,6 +64,9 @@ async def list_conversations():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
+        
         conversation_client = init_database_client()
         if not conversation_client:
             return jsonify({"error": "Database not available"}), 500
@@ -70,7 +74,7 @@ async def list_conversations():
         await conversation_client.connect()
         try:
             conversations = await conversation_client.get_conversations(
-                user_id, offset=offset, limit=25
+                user_id, offset=offset, limit=25, tenant_id=tenant_id
             )
             if not isinstance(conversations, list):
                 return (
@@ -102,6 +106,8 @@ async def rename_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
 
         # check request for conversation_id
         request_json = request.get_json()
@@ -123,7 +129,7 @@ async def rename_conversation():
         try:
             # Retrieve conversation from database
             conversation = await conversation_client.get_conversation(
-                user_id, conversation_id
+                user_id, conversation_id, tenant_id=tenant_id
             )
             if not conversation:
                 return (
@@ -138,7 +144,7 @@ async def rename_conversation():
             # Update the title and save changes
             conversation["title"] = title
             updated_conversation = await conversation_client.upsert_conversation(
-                conversation
+                conversation, tenant_id=tenant_id
             )
             return jsonify(updated_conversation), 200
         except Exception as e:
@@ -165,6 +171,8 @@ async def get_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
 
         # check request for conversation_id
         request_json = request.get_json()
@@ -181,7 +189,7 @@ async def get_conversation():
         try:
             # Retrieve conversation
             conversation = await conversation_client.get_conversation(
-                user_id, conversation_id
+                user_id, conversation_id, tenant_id=tenant_id
             )
             if not conversation:
                 return (
@@ -195,7 +203,7 @@ async def get_conversation():
 
             # Fetch conversation messages
             conversation_messages = await conversation_client.get_messages(
-                user_id, conversation_id
+                user_id, conversation_id, tenant_id=tenant_id
             )
             messages = [
                 {
@@ -239,6 +247,9 @@ async def delete_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
+        
         # check request for conversation_id
         request_json = request.get_json()
         conversation_id = request_json.get("conversation_id", None)
@@ -260,10 +271,10 @@ async def delete_conversation():
         await conversation_client.connect()
         try:
             # Delete conversation messages from database
-            await conversation_client.delete_messages(conversation_id, user_id)
+            await conversation_client.delete_messages(conversation_id, user_id, tenant_id=tenant_id)
 
             # Delete the conversation itself
-            await conversation_client.delete_conversation(user_id, conversation_id)
+            await conversation_client.delete_conversation(user_id, conversation_id, tenant_id=tenant_id)
 
             return (
                 jsonify(
@@ -302,6 +313,9 @@ async def delete_all_conversations():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
+        
         # Initialize the database client
         conversation_client = init_database_client()
         if not conversation_client:
@@ -311,7 +325,7 @@ async def delete_all_conversations():
         try:
             # Get all conversations for the user
             conversations = await conversation_client.get_conversations(
-                user_id, offset=0, limit=None
+                user_id, offset=0, limit=None, tenant_id=tenant_id
             )
             if not conversations:
                 return (
@@ -324,12 +338,12 @@ async def delete_all_conversations():
                 try:
                     # Delete messages associated with the conversation
                     await conversation_client.delete_messages(
-                        conversation["id"], user_id
+                        conversation["id"], user_id, tenant_id=tenant_id
                     )
 
                     # Delete the conversation itself
                     await conversation_client.delete_conversation(
-                        user_id, conversation["id"]
+                        user_id, conversation["id"], tenant_id=tenant_id
                     )
 
                 except Exception as e:
@@ -372,6 +386,9 @@ async def update_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
+        client_principal_b64 = authenticated_user.get("client_principal_b64")
+        tenant_id = get_tenantid(client_principal_b64)
+        
         request_json = request.get_json()
         conversation_id = request_json.get("conversation_id", None)
         if not conversation_id:
@@ -389,12 +406,12 @@ async def update_conversation():
         try:
             # Get or create the conversation
             conversation = await conversation_client.get_conversation(
-                user_id, conversation_id
+                user_id, conversation_id, tenant_id=tenant_id
             )
             if not conversation:
                 title = await generate_title(messages)
                 conversation = await conversation_client.create_conversation(
-                    user_id=user_id, conversation_id=conversation_id, title=title
+                    user_id=user_id, conversation_id=conversation_id, title=title, tenant_id=tenant_id
                 )
 
             # Process and save user and assistant messages
@@ -411,6 +428,7 @@ async def update_conversation():
                     conversation_id=conversation_id,
                     user_id=user_id,
                     input_message=user_message,
+                    tenant_id=tenant_id,
                 )
                 if created_message == "Conversation not found":
                     return jsonify({"error": "Conversation not found"}), 400
@@ -424,6 +442,7 @@ async def update_conversation():
                         conversation_id=conversation_id,
                         user_id=user_id,
                         input_message=messages[-2],
+                        tenant_id=tenant_id,
                     )
                 # Write the assistant message
                 await conversation_client.create_message(
@@ -431,6 +450,7 @@ async def update_conversation():
                     conversation_id=conversation_id,
                     user_id=user_id,
                     input_message=messages[-1],
+                    tenant_id=tenant_id,
                 )
             else:
                 return jsonify({"error": "No assistant message found"}), 400
