@@ -21,8 +21,9 @@ class Orchestrator:
         chat_history: List[dict],
         conversation_id: str,
         user_info,
+        tenant_id: str = None,
         **kwargs: dict,
     ) -> dict:
         return await self.orchestrator.handle_message(
-            user_message, chat_history, conversation_id, user_info, **kwargs
+            user_message, chat_history, conversation_id, user_info, tenant_id, **kwargs
         )
